
/*==============DEFAULT STYLE CSS=============*/

:root {
    --md-admonition-icon--note: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="#448aff"><path d="M20.71 7.04c.39-.39.39-1.04 0-1.41l-2.34-2.34c-.37-.39-1.02-.39-1.41 0l-1.84 1.83 3.75 3.75M3 17.25V21h3.75L17.81 9.93l-3.75-3.75L3 17.25Z"/></svg>');
    --md-admonition-icon--abstract: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="#00b0ff"><path d="M17 9H7V7h10m0 6H7v-2h10m-3 6H7v-2h7M12 3a1 1 0 0 1 1 1 1 1 0 0 1-1 1 1 1 0 0 1-1-1 1 1 0 0 1 1-1m7 0h-4.18C14.4 1.84 13.3 1 12 1c-1.3 0-2.4.84-2.82 2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2V5a2 2 0 0 0-2-2Z"/></svg>');
    --md-admonition-icon--info: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="#00b8d4"><path d="M13 9h-2V7h2m0 10h-2v-6h2m-1-9A10 10 0 0 0 2 12a10 10 0 0 0 10 10 10 10 0 0 0 10-10A10 10 0 0 0 12 2Z"/></svg>');
    --md-admonition-icon--tip: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="#00bfa5"><path d="M17.66 11.2c-.23-.3-.51-.56-.77-.82-.67-.6-1.43-1.03-2.07-1.66C13.33 7.26 13 4.85 13.95 3c-.95.23-1.78.75-2.49 1.32-2.59 2.08-3.61 5.75-2.39 8.9.04.1.08.2.08.33 0 .22-.15.42-.35.5-.23.1-.47.04-.66-.12a.58.58 0 0 1-.14-.17c-1.13-1.43-1.31-3.48-.55-5.12C5.78 10 4.87 12.3 5 14.47c.06.5.12 1 .29 1.5.14.6.41 1.2.71 1.73 1.08 1.73 2.95 2.97 4.96 3.22 2.14.27 4.43-.12 6.07-1.6 1.83-1.66 2.47-4.32 1.53-6.6l-.13-.26c-.21-.46-.77-1.26-.77-1.26m-3.16 6.3c-.28.24-.74.5-1.1.6-1.12.4-2.24-.16-2.9-.82 1.19-.28 1.9-1.16 2.11-2.05.17-.8-.15-1.46-.28-2.23-.12-.74-.1-1.37.17-2.06.19.38.39.76.63 1.06.77 1 1.98 1.44 2.24 2.8.04.14.06.28.06.43.03.82-.33 1.72-.93 2.27Z"/></svg>');
    --md-admonition-icon--success: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="#00c853"><path d="m9 20.42-6.21-6.21 2.83-2.83L9 14.77l9.88-9.89 2.83 2.83L9 20.42Z"/></svg>');
    --md-admonition-icon--question: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="#64dd17"><path d="m15.07 11.25-.9.92C13.45 12.89 13 13.5 13 15h-2v-.5c0-1.11.45-2.11 1.17-2.83l1.24-1.26c.37-.36.59-.86.59-1.41a2 2 0 0 0-2-2 2 2 0 0 0-2 2H8a4 4 0 0 1 4-4 4 4 0 0 1 4 4 3.2 3.2 0 0 1-.93 2.25M13 19h-2v-2h2M12 2A10 10 0 0 0 2 12a10 10 0 0 0 10 10 10 10 0 0 0 10-10c0-5.53-4.5-10-10-10Z"/></svg>');
    --md-admonition-icon--warning: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="#ff9100"><path d="M13 14h-2V9h2m0 9h-2v-2h2M1 21h22L12 2 1 21Z"/></svg>');
    --md-admonition-icon--failure: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="#ff5252"><path d="M20 6.91 17.09 4 12 9.09 6.91 4 4 6.91 9.09 12 4 17.09 6.91 20 12 14.91 17.09 20 20 17.09 14.91 12 20 6.91Z"/></svg>');
    --md-admonition-icon--danger: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="#ff1744"><path d="M11 15H6l7-14v8h5l-7 14v-8Z"/></svg>');
    --md-admonition-icon--bug: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="#f50057"><path d="M14 12h-4v-2h4m0 6h-4v-2h4m6-6h-2.81a5.985 5.985 0 0 0-1.82-1.96L17 4.41 15.59 3l-2.17 2.17a6.002 6.002 0 0 0-2.83 0L8.41 3 7 4.41l1.62 1.63C7.88 6.55 7.26 7.22 6.81 8H4v2h2.09c-.05.33-.09.66-.09 1v1H4v2h2v1c0 .34.04.67.09 1H4v2h2.81c1.04 1.79 2.97 3 5.19 3s4.15-1.21 5.19-3H20v-2h-2.09c.05-.33.09-.66.09-1v-1h2v-2h-2v-1c0-.34-.04-.67-.09-1H20V8Z"/></svg>');
    --md-admonition-icon--example: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16" fill="#7c4dff"><path fill-rule="evenodd" d="M5 5.782V2.5h-.25a.75.75 0 010-1.5h6.5a.75.75 0 010 1.5H11v3.282l3.666 5.76C15.619 13.04 14.543 15 12.767 15H3.233c-1.776 0-2.852-1.96-1.899-3.458L5 5.782zM9.5 2.5h-3V6a.75.75 0 01-.117.403L4.73 9h6.54L9.617 6.403A.75.75 0 019.5 6V2.5zm-6.9 9.847L3.775 10.5h8.45l1.175 1.847a.75.75 0 01-.633 1.153H3.233a.75.75 0 01-.633-1.153z"></path></svg>');
    --md-admonition-icon--quote: url('data:image/svg+xml;charset=utf-8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="#9e9e9e"><path d="M14 17h3l2-4V7h-6v6h3M6 17h3l2-4V7H5v6h3l-2 4Z"/></svg>');
}

body {
    background: none;
    background-color: #fff;
    font-family: var(--md-text-font), sans-serif;
    font-size: 12pt;
  }

a.md-content__button.md-icon{
    display: none;
}

/* Tabbed-Content */
div.tabbed-content {
  display: none;
}
div.tabbed-labels {
    display: block !important;
}

/* Admonitions */
.md-typeset :is(.note)>:is(.admonition-title,summary):before{
    color: #448aff;
    background-color: transparent;
    content: var(--md-admonition-icon--note);
}
.md-typeset :is(.abstract, .summary, .tldr)>:is(.admonition-title,summary):before{
    color: #00b0ff;
    background-color: transparent;
    content: var(--md-admonition-icon--abstract);
}
.md-typeset :is(.info, .todo)>:is(.admonition-title,summary):before{
    color: #00b8d4;
    background-color: transparent;
    content: var(--md-admonition-icon--info);
}
.md-typeset :is(.tip, .hint, .important)>:is(.admonition-title,summary):before{
    color: #00bfa5;
    background-color: transparent;
    content: var(--md-admonition-icon--tip);
}
.md-typeset :is(.success, .check, .done)>:is(.admonition-title,summary):before{
    color: #00c853;
    background-color: transparent;
    content: var(--md-admonition-icon--success);
}
.md-typeset :is(.question, .help, .faq)>:is(.admonition-title,summary):before{
    color: #64dd17;
    background-color: transparent;
    content: var(--md-admonition-icon--question);
}
.md-typeset :is(.warning, .caution, .attention)>:is(.admonition-title,summary):before{
    color: #ff9100;
    background-color: transparent;
    content: var(--md-admonition-icon--warning);
}
.md-typeset :is(.failure, .fail, .missing)>:is(.admonition-title,summary):before{
    color: #ff5252;
    background-color: transparent;
    content: var(--md-admonition-icon--failure);
}
.md-typeset :is(.danger, .error)>:is(.admonition-title,summary):before{
    color: #ff1744;
    background-color: transparent;
    content: var(--md-admonition-icon--danger);
}
.md-typeset :is(.bug)>:is(.admonition-title,summary):before{
    color: #f50057;
    background-color: transparent;
    content: var(--md-admonition-icon--bug);
}
.md-typeset :is(.example)>:is(.admonition-title,summary):before{
    color: #7c4dff;
    background-color: transparent;
    content: var(--md-admonition-icon--example);
}
.md-typeset :is(.quote)>:is(.admonition-title,summary):before{
    color: #9e9e9e;
    background-color: transparent;
    content: var(--md-admonition-icon--quote);
}
.md-typeset :is(.admonition, details) {
   border-width: 0.5px 0.5px 0.5px .2rem;
   border-style: solid;
   display: block;
}
:is(.note, .abstract, .info, .tip, .success, .question, .warning, .caution, .check, .done,
.todo, .summary, .tldr, .failure, .danger, .bug, .example, .quote, .hint, .error, .important,
.attention, .help, .faq, .fail, .missing, .cite) summary::after {
   display:none;
}

.admonition.note .admonition-title::before {
    color: #448aff;
    background-color: transparent;
    content: var(--md-admonition-icon--note);
}
.admonition:is(.abstract, .summary, .tldr) .admonition-title::before {
    color: #00b0ff;
    background-color: transparent;
    content: var(--md-admonition-icon--abstract);
}
.admonition:is(.info, .todo) .admonition-title::before {
    color: #00b8d4;
    background-color: transparent;
    content: var(--md-admonition-icon--info);
}
.admonition:is(.tip, .hint, .important) .admonition-title::before {
    color: #00bfa5;
    background-color: transparent;
    content: var(--md-admonition-icon--tip);
}
.admonition:is(.success, .check, .done) .admonition-title::before {
    color: #00c853;
    background-color: transparent;
    content: var(--md-admonition-icon--success);
}
.admonition:is(.question, .help, .faq) .admonition-title::before {
    color: #64dd17;
    background-color: transparent;
    content: var(--md-admonition-icon--question);
}
.admonition:is(.warning, .caution, .attention) .admonition-title::before {
    color: #ff9100;
    background-color: transparent;
    content: var(--md-admonition-icon--warning);
}
.admonition:is(.failure, .fail, .missing) .admonition-title::before {
    color: #ff5252;
    background-color: transparent;
    content: var(--md-admonition-icon--failure);
}
.admonition:is(.danger, .error) .admonition-title::before {
    color: #ff1744;
    background-color: transparent;
    content: var(--md-admonition-icon--danger);
}
.admonition.bug .admonition-title::before {
    color: #f50057;
    background-color: transparent;
    content: var(--md-admonition-icon--bug);
}
.admonition.example .admonition-title::before {
    color: #7c4dff;
    background-color: transparent;
    content: var(--md-admonition-icon--example);
}
.admonition:is(.quote, .cite) .admonition-title::before {
    color: #9e9e9e;
    background-color: transparent;
    content: var(--md-admonition-icon--quote);
}

nav.md-tags{
    display: none;
}
table {
    max-width: 100%;
}

div.md-typeset__table table{
    border-radius: .1rem;
    display: table;
    font-size: .64rem;
    max-width: 100%;
    overflow: auto;
    border-collapse: initial;
    border-spacing: 0;
}

.md-typeset table:not([class]) {
    font-size: 14px;
    line-height: 1.5;
}
.md-typeset .tabbed-set{
    display: block;
}
.md-typeset .tabbed-set .tabbed-content--wrap {
    display: inline-block;
    width: 100%;
    margin-bottom: 0.25rem;
}
.md-typeset .tabbed-set .tabbed-content--wrap input{
    display: none;
}
.md-typeset .tabbed-set .tabbed-content--wrap label{
    background-color: #aaa;
    padding: 0.2rem 2rem;
    margin: 0;
    font-weight: 600;
    color: #666;
    border-radius: 3px 3px 0 0;
    border-bottom-color: transparent;
}
.md-typeset .tabbed-set .tabbed-content--wrap .tabbed-content{
    display: block;
    box-shadow: none;
}
div[data-md-component="sidebar"],
div[id="custom-banner"],
div[data-md-component="skip"],
div[data-md-component="announce"],
div[data-md-component="header"],
header[data-md-component="header"],
label[class="md-overlay"] {
    display: none;
}

h2 {
    string-set: chapter content();
}

.md-typeset .headerlink {
    display: none
}

/* Tables */
.md-typeset table {
    background-color: transparent;
    border-radius: 0;
    font-size: 8pt;
    border: 1px solid gray;
    margin: auto;
}

.md-typeset dd table:not([class]) {
    margin: unset;
}

.md-typeset table th {
    padding: 2mm 2.5mm;
}

.md-typeset table td {
    border-top: 1px solid lightgray;
    padding: 2mm 2.5mm;
}

/* Fixes Table Width */
.md-typeset__table {
    display: table;
    margin: auto;
}

.md-typeset__table>table {
    display: table;
    margin: auto;
}

.admonition .md-typeset__table,
.md-content__inner.md-typeset details .md-typeset__table {
    width: 100%;
}

.md-typeset table {
    display: table;
}

.md-typeset table td {
    vertical-align: middle;
}

dl>dd>.md-typeset__scrollwrap>.md-typeset__table {
    min-width: 50%;
    margin: 0;
}

.md-typeset table:not([class]) th:empty {
    padding: 0;
}