/*==============PAGE CSS=============*/

@media print {
  @page {
    counter-increment: page;
    size: var(--base-page-orientation);
    margin: 10mm 10mm 15mm 10mm;

    @top-right {
        content: var(--author);
        font-size: 9pt;
    }

    @top-left {
        content: string(chapter);
        font-size: 9pt;
    }
    @bottom-center {
        content: var(--type);
        font-size: 10pt;
        font-weight: 600;
        text-transform: capitalize;
    }
    @bottom-right {
        content: "Page " counter(page) " of " counter(pages);
        font-size: 8pt;
    }
    @bottom-left {
        content: var(--site-url);
        font-size: 8pt;
    }
  }

  @page rotated {
    size: var(--rotated-page-orientation);
  }

  .rotated-page {
    page: rotated;
    page-break-before: always;
    page-break-after: always;
  }

  .page-break {
    break-before: always;
  }

  code,
  kbd,
  pre {
    font-family: var(--md-code-font), monospace;
    margin-top: 0;
  }

  label.sd-tab-label, div.sd-tab-set {
    display: block !important;
  }

  div.new_tabbed_block {
    display: block;
  }

  .sd-tab-set > label {
	border: none;
	color: #000000de;
	font-size: 14px;
	font-weight: 700;
	padding: .5em 0;
  }

  .sd-tab-set > input:checked + label {
	color: #000000de;
  }
}

